==> scraping-1.1.21-sources.jar: com/tenqube/visual_scraper/db/DataGenerator.java <==
/*
 * Copyright 2017, The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.tenqube.visual_scraper.db;

import java.util.ArrayList;
import java.util.List;

/**
 * Generates data to pre-populate the database
 */
public class DataGenerator {

    public static void generatesOrderRules() {



    }


//    public static List<ScrapEntity> generateScraps() {
//        List<ScrapEntity> scrapEntities = new ArrayList<>();
////        Random rnd = new Random();
////        for (int i = 0; i < FIRST.length; i++) {
////            for (int j = 0; j < SECOND.length; j++) {
////                OrderEntity product = new OrderEntity();
////                product.setName(FIRST[i] + " " + SECOND[j]);
////                product.setDescription(product.getName() + " " + DESCRIPTION[j]);
////                product.setPrice(rnd.nextInt(240));
////                product.setId(FIRST.length * i + j + 1);
////                products.add(product);
////            }
////        }
//        return scrapEntities;
//    }




}

==> scraping-1.2.4-sources.jar: com/tenqube/visual_scraper/db/DataGenerator.java <==
/*
 * Copyright 2017, The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.tenqube.visual_scraper.db;

import android.content.Context;

import com.tenqube.visual_scraper.db.entity.MallEntity;
import com.tenqube.visual_scraper.model.api.response.MallResponse;
import com.tenqube.visual_scraper.model.api.response.RuleResponse;
import com.tenqube.visual_scraper.utils.Utils;

import java.util.ArrayList;
import java.util.List;

/**
 * Generates data to pre-populate the database
 */
public class DataGenerator {

    public static List<MallEntity> createMalls(Context context) {

        String malls = Utils.loadJSONFromAsset(context, "mall.json");
        RuleResponse res = Utils.parseJsonObject(malls, RuleResponse.class);

        List<MallEntity> mallEntities = new ArrayList<>();

        if(res != null) {
            for(MallResponse m : res.getMalls()) {
                mallEntities.add(m.toEntity());
            }
        }

        return mallEntities;
    }


//    public static List<ScrapEntity> generateScraps() {
//        List<ScrapEntity> scrapEntities = new ArrayList<>();
////        Random rnd = new Random();
////        for (int i = 0; i < FIRST.length; i++) {
////            for (int j = 0; j < SECOND.length; j++) {
////                OrderEntity product = new OrderEntity();
////                product.setName(FIRST[i] + " " + SECOND[j]);
////                product.setDescription(product.getName() + " " + DESCRIPTION[j]);
////                product.setPrice(rnd.nextInt(240));
////                product.setId(FIRST.length * i + j + 1);
////                products.add(product);
////            }
////        }
//        return scrapEntities;
//    }




}
